@@ -22,11 +22,11 @@ from aliyunsdkcore.request import RpcRequest
 class CheckAliyunAccountExistsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'CheckAliyunAccountExists','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'CheckAliyunAccountExists')
 		self.set_method('POST')
 
-	def get_UserPk(self):
+	def get_UserPk(self): # String
 		return self.get_body_params().get('UserPk')
 
-	def set_UserPk(self,UserPk):
-		self.add_body_params('UserPk', UserPk)
\ No newline at end of file
+	def set_UserPk(self, UserPk):  # String
+		self.add_body_params('UserPk', UserPk)
