@@ -22,23 +22,21 @@ from aliyunsdkcore.request import RpcRequest
 class CreatePipelineRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'CreatePipeline','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'CreatePipeline')
 		self.set_method('POST')
 
-	def get_Pipeline(self):
+	def get_Pipeline(self): # String
 		return self.get_body_params().get('Pipeline')
 
-	def set_Pipeline(self,Pipeline):
+	def set_Pipeline(self, Pipeline):  # String
 		self.add_body_params('Pipeline', Pipeline)
-
-	def get_UserPk(self):
+	def get_UserPk(self): # String
 		return self.get_body_params().get('UserPk')
 
-	def set_UserPk(self,UserPk):
+	def set_UserPk(self, UserPk):  # String
 		self.add_body_params('UserPk', UserPk)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
