@@ -22,23 +22,21 @@ from aliyunsdkcore.request import RpcRequest
 class DeleteDevopsProjectMembersRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'DeleteDevopsProjectMembers','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'DeleteDevopsProjectMembers')
 		self.set_method('POST')
 
-	def get_UserIds(self):
+	def get_UserIds(self): # String
 		return self.get_body_params().get('UserIds')
 
-	def set_UserIds(self,UserIds):
+	def set_UserIds(self, UserIds):  # String
 		self.add_body_params('UserIds', UserIds)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # String
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # String
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
