@@ -22,17 +22,16 @@ from aliyunsdkcore.request import RpcRequest
 class GetDevopsProjectSprintInfoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'GetDevopsProjectSprintInfo','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'GetDevopsProjectSprintInfo')
 		self.set_method('POST')
 
-	def get_SprintId(self):
+	def get_SprintId(self): # String
 		return self.get_body_params().get('SprintId')
 
-	def set_SprintId(self,SprintId):
+	def set_SprintId(self, SprintId):  # String
 		self.add_body_params('SprintId', SprintId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
