@@ -22,29 +22,26 @@ from aliyunsdkcore.request import RpcRequest
 class GetPipelineInstanceGroupStatusRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'GetPipelineInstanceGroupStatus','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'GetPipelineInstanceGroupStatus')
 		self.set_method('POST')
 
-	def get_FlowInstanceId(self):
+	def get_FlowInstanceId(self): # Long
 		return self.get_body_params().get('FlowInstanceId')
 
-	def set_FlowInstanceId(self,FlowInstanceId):
+	def set_FlowInstanceId(self, FlowInstanceId):  # Long
 		self.add_body_params('FlowInstanceId', FlowInstanceId)
-
-	def get_UserPk(self):
+	def get_UserPk(self): # String
 		return self.get_body_params().get('UserPk')
 
-	def set_UserPk(self,UserPk):
+	def set_UserPk(self, UserPk):  # String
 		self.add_body_params('UserPk', UserPk)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_query_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_query_param('OrgId',OrgId)
-
-	def get_PipelineId(self):
+	def set_OrgId(self, OrgId):  # String
+		self.add_query_param('OrgId', OrgId)
+	def get_PipelineId(self): # Long
 		return self.get_query_params().get('PipelineId')
 
-	def set_PipelineId(self,PipelineId):
-		self.add_query_param('PipelineId',PipelineId)
\ No newline at end of file
+	def set_PipelineId(self, PipelineId):  # Long
+		self.add_query_param('PipelineId', PipelineId)
