@@ -22,23 +22,21 @@ from aliyunsdkcore.request import RpcRequest
 class GetTaskDetailActivityRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'GetTaskDetailActivity','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'GetTaskDetailActivity')
 		self.set_method('POST')
 
-	def get_ProjectId(self):
+	def get_ProjectId(self): # String
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # String
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
+	def set_OrgId(self, OrgId):  # String
 		self.add_body_params('OrgId', OrgId)
-
-	def get_TaskId(self):
+	def get_TaskId(self): # String
 		return self.get_body_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_body_params('TaskId', TaskId)
\ No newline at end of file
+	def set_TaskId(self, TaskId):  # String
+		self.add_body_params('TaskId', TaskId)
