@@ -25,14 +25,23 @@ class ListDevopsProjectSprintsRequest(RpcRequest):
 		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectSprints')
 		self.set_method('POST')
 
-	def get_ProjectId(self):
+	def get_PageSize(self): # Long
+		return self.get_body_params().get('PageSize')
+
+	def set_PageSize(self, PageSize):  # Long
+		self.add_body_params('PageSize', PageSize)
+	def get_ProjectId(self): # String
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # String
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
+	def get_PageToken(self): # String
+		return self.get_body_params().get('PageToken')
+
+	def set_PageToken(self, PageToken):  # String
+		self.add_body_params('PageToken', PageToken)
