@@ -22,17 +22,16 @@ from aliyunsdkcore.request import RpcRequest
 class ListDevopsProjectTaskFlowRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTaskFlow','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTaskFlow')
 		self.set_method('POST')
 
-	def get_ProjectId(self):
+	def get_ProjectId(self): # String
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # String
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
