@@ -25,14 +25,13 @@ class ListDevopsProjectTaskListRequest(RpcRequest):
 		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTaskList')
 		self.set_method('POST')
 
-	def get_ProjectId(self):
+	def get_ProjectId(self): # String
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # String
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
