@@ -22,17 +22,16 @@ from aliyunsdkcore.request import RpcRequest
 class ListDevopsProjectTasksRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTasks','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTasks')
 		self.set_method('POST')
 
-	def get_ProjectIds(self):
+	def get_ProjectIds(self): # String
 		return self.get_body_params().get('ProjectIds')
 
-	def set_ProjectIds(self,ProjectIds):
+	def set_ProjectIds(self, ProjectIds):  # String
 		self.add_body_params('ProjectIds', ProjectIds)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_body_params('OrgId', OrgId)
\ No newline at end of file
+	def set_OrgId(self, OrgId):  # String
+		self.add_body_params('OrgId', OrgId)
