@@ -22,29 +22,26 @@ from aliyunsdkcore.request import RpcRequest
 class TransferPipelineOwnerRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'TransferPipelineOwner','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'TransferPipelineOwner')
 		self.set_method('POST')
 
-	def get_UserPk(self):
+	def get_UserPk(self): # String
 		return self.get_body_params().get('UserPk')
 
-	def set_UserPk(self,UserPk):
+	def set_UserPk(self, UserPk):  # String
 		self.add_body_params('UserPk', UserPk)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_query_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
-		self.add_query_param('OrgId',OrgId)
-
-	def get_PipelineId(self):
+	def set_OrgId(self, OrgId):  # String
+		self.add_query_param('OrgId', OrgId)
+	def get_PipelineId(self): # Long
 		return self.get_query_params().get('PipelineId')
 
-	def set_PipelineId(self,PipelineId):
-		self.add_query_param('PipelineId',PipelineId)
-
-	def get_NewOwnerId(self):
+	def set_PipelineId(self, PipelineId):  # Long
+		self.add_query_param('PipelineId', PipelineId)
+	def get_NewOwnerId(self): # String
 		return self.get_body_params().get('NewOwnerId')
 
-	def set_NewOwnerId(self,NewOwnerId):
-		self.add_body_params('NewOwnerId', NewOwnerId)
\ No newline at end of file
+	def set_NewOwnerId(self, NewOwnerId):  # String
+		self.add_body_params('NewOwnerId', NewOwnerId)
