@@ -22,41 +22,36 @@ from aliyunsdkcore.request import RpcRequest
 class UpdateCommonGroupRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'UpdateCommonGroup','1.9.6')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'UpdateCommonGroup')
 		self.set_method('POST')
 
-	def get_Description(self):
+	def get_Description(self): # String
 		return self.get_body_params().get('Description')
 
-	def set_Description(self,Description):
+	def set_Description(self, Description):  # String
 		self.add_body_params('Description', Description)
-
-	def get_CommonGroupId(self):
+	def get_CommonGroupId(self): # String
 		return self.get_body_params().get('CommonGroupId')
 
-	def set_CommonGroupId(self,CommonGroupId):
+	def set_CommonGroupId(self, CommonGroupId):  # String
 		self.add_body_params('CommonGroupId', CommonGroupId)
-
-	def get_OrgId(self):
+	def get_OrgId(self): # String
 		return self.get_body_params().get('OrgId')
 
-	def set_OrgId(self,OrgId):
+	def set_OrgId(self, OrgId):  # String
 		self.add_body_params('OrgId', OrgId)
-
-	def get_SmartGroupId(self):
+	def get_SmartGroupId(self): # String
 		return self.get_body_params().get('SmartGroupId')
 
-	def set_SmartGroupId(self,SmartGroupId):
+	def set_SmartGroupId(self, SmartGroupId):  # String
 		self.add_body_params('SmartGroupId', SmartGroupId)
-
-	def get_Name(self):
+	def get_Name(self): # String
 		return self.get_body_params().get('Name')
 
-	def set_Name(self,Name):
+	def set_Name(self, Name):  # String
 		self.add_body_params('Name', Name)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # String
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
-		self.add_body_params('ProjectId', ProjectId)
\ No newline at end of file
+	def set_ProjectId(self, ProjectId):  # String
+		self.add_body_params('ProjectId', ProjectId)
